@@ -1,8 +1,8 @@
-__version__ = VERSION = 0, 0, 2
+__version__ = VERSION = 0, 0, 3
 __versionstr__ = '.'.join(map(str, VERSION))
 
 try:
-    from smartadmin.admin import SmartAdmin
+    from smartadmin.admin import SmartAdmin, filter_existing
     # this only works inside a django project...
 except ImportError:
     pass
